
/*
	OutputThermal.c: output model results for thermal solution.
*/
#undef __FUNCT__ 
#define __FUNCT__ "OutputThermal"

#include "../toolkits/toolkits.h"
#include "../EnumDefinitions/EnumDefinitions.h"
#include "../shared/shared.h"
#include "../io/io.h"
#include "../objects/objects.h"

void OutputThermal(Vec* t_g,Vec* m_g, FemModel* femmodels,char* filename){

	int i;
	extern int my_rank;
	
	/* output: */
	FILE* fid=NULL;

	/*intermediary: */
	FemModel  femmodel;
	NodeSets* nodesets=NULL;
	Vec       partition=NULL;
	char*     analysis_type="thermal";
	
	/* standard output: */
	Vec partition_shifted=NULL;
	double* serial_partition=NULL;

	double* serial_tg=NULL;
	double* serial_mg=NULL;

	double ndt,dt;
	int    nsteps;
	int    sub_analysis_type;
	
	int     one=1;
	int     gsize;
	int     nods;

	/*Recover thermal horiz femmodel: */
	femmodel=femmodels[0];
	partition=femmodel.partition;
	nodesets=femmodel.nodesets;

	femmodels[0].parameters->FindParam((void*)&dt,"dt");
	femmodels[0].parameters->FindParam((void*)&ndt,"ndt");
	femmodels[0].parameters->FindParam((void*)&sub_analysis_type,"sub_analysis_type");

	/*serialize outputs: */
	VecDuplicate(partition,&partition_shifted);
	VecCopy(partition,partition_shifted);
	VecShift(partition_shifted,1.0); //matlab indexing starts at 1
	VecToMPISerial(&serial_partition,partition_shifted);
	VecGetSize(partition,&nods);

	if(sub_analysis_type==SteadyAnalysisEnum()){
		nsteps=0;
	}
	else{
		nsteps=(int)(ndt/dt);
	}

	/* Open output file to write raw binary data: */
	if(my_rank==0){
		fid=pfopen(filename,"wb");

		/*Write solution type: */
		WriteDataToDisk(analysis_type,NULL,NULL,"String",fid);

		/*Write uset.gsize: */
		gsize=nodesets->GetGSize();
		WriteDataToDisk(&gsize,NULL,NULL,"Integer",fid);

		/*Write partition: */
		WriteDataToDisk(serial_partition,&nods,&one,"Mat",fid);
		
		/*Write number of steps: */
		WriteDataToDisk(&nsteps,NULL,NULL,"Integer",fid);

		/*Write solutions to disk: */
		for(i=0;i<=nsteps;i++){
	
			xfree((void**)&serial_tg);
			xfree((void**)&serial_mg);
			VecToMPISerial(&serial_tg,t_g[i]);
			VecToMPISerial(&serial_mg,m_g[i]);

			WriteDataToDisk(serial_tg,&gsize,&one,"Mat",fid);
			WriteDataToDisk(serial_mg,&gsize,&one,"Mat",fid);
		}
	
		/*Close file: */
		pfclose(fid,filename);
	}

	/*Free ressources: */
	VecFree(&partition_shifted);
	xfree((void**)&serial_partition);
	xfree((void**)&serial_tg);
	xfree((void**)&serial_mg);
}	
